@@ -6,6 +6,7 @@
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <errno.h>
 #include <glib.h>
 #include <gio/gio.h>
 #include "format.h"
@@ -41,8 +42,8 @@ slurp_files (const char *full_path, const char *relative_path, const char *name)
 
   if (res != 0)
     {
-      g_free (file);
-      return NULL;
+      g_printerr ("Can't read file %s: %s\n", full_path, strerror (errno));
+      exit (1);
     }
 
   file->name = g_strdup (name);
